@@ -79,11 +79,11 @@
 # If possible, the script will use pdftocairo instead of gs,
 # as it's much faster and gives better results.
 
-import glob, os, pipes, re, string, sys
+import glob, os, pipes, re, sys, tempfile
 
 from lyxpreview_tools import check_latex_log, copyfileobj, error, filter_pages,\
      find_exe, find_exe_or_terminate, join_metrics_and_rename, latex_commands, \
-     latex_file_re, make_texcolor, mkstemp, pdflatex_commands, progress, \
+     latex_file_re, make_texcolor, pdflatex_commands, progress, \
      run_command, run_latex, warning, write_metrics_info
 
 
@@ -118,8 +118,8 @@ def legacy_extract_metrics_info(log_file):
                 error("Unexpected data in %s\n%s" % (log_file, line))
 
             if snippet:
-                ascent  = string.atof(match.group(2))
-                descent = string.atof(match.group(3))
+                ascent  = float(match.group(2))
+                descent = float(match.group(3))
 
                 frac = 0.5
                 if ascent == 0 and descent == 0:
@@ -139,14 +139,14 @@ def legacy_extract_metrics_info(log_file):
                 results.append((int(match.group(1)), frac))
 
             else:
-                tp_descent = string.atof(match.group(2))
-                tp_ascent  = string.atof(match.group(4))
+                tp_descent = float(match.group(2))
+                tp_ascent  = float(match.group(4))
 
     except:
         # Unable to open the file, but do nothing here because
         # the calling function will act on the value of 'success'.
         warning('Warning in legacy_extract_metrics_info! Unable to open "%s"' % log_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
     if success == 0:
         error("Failed to extract metrics info from %s" % log_file)
@@ -177,7 +177,7 @@ def extract_resolution(log_file, dpi):
                     match = extract_decimal_re.search(line)
                     if match == None:
                         error("Unable to parse: %s" % line)
-                    fontsize = string.atof(match.group(1))
+                    fontsize = float(match.group(1))
                     found_fontsize = 1
                     continue
 
@@ -187,13 +187,13 @@ def extract_resolution(log_file, dpi):
                     match = extract_integer_re.search(line)
                     if match == None:
                         error("Unable to parse: %s" % line)
-                    magnification = string.atof(match.group(1))
+                    magnification = float(match.group(1))
                     found_magnification = 1
                     continue
 
     except:
         warning('Warning in extract_resolution! Unable to open "%s"' % log_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
     # This is safe because both fontsize and magnification have
     # non-zero default values.
@@ -201,48 +201,74 @@ def extract_resolution(log_file, dpi):
 
 
 def legacy_latex_file(latex_file, fg_color, bg_color):
-    use_preview_re = re.compile(r"\s*\\usepackage\[([^]]+)\]{preview}")
+    use_polyglossia_re = re.compile(b"\\s*\\\\usepackage{polyglossia}")
+    use_preview_re = re.compile(b"\\s*\\\\usepackage\\[([^]]+)\\]{preview}")
     fg_color_gr = make_texcolor(fg_color, True)
     bg_color_gr = make_texcolor(bg_color, True)
 
-    tmp = mkstemp()
+    tmp = tempfile.TemporaryFile()
 
     success = 0
     try:
-        f = open(latex_file, 'r')
+        f = open(latex_file, 'rb')
     except:
         # Unable to open the file, but do nothing here because
         # the calling function will act on the value of 'success'.
         warning('Warning in legacy_latex_file! Unable to open "%s"' % latex_file)
-        warning(`sys.exc_type` + ',' + `sys.exc_value`)
+        warning(repr(sys.exc_info()[0]) + ',' + repr(sys.exc_info()[1]))
 
+    polyglossia = False
     for line in f.readlines():
         if success:
             tmp.write(line)
             continue
         match = use_preview_re.match(line)
+        polymatch = use_polyglossia_re.match(line)
+        # Package order:
+        # * if polyglossia is used, we need to load color before that
+        #   (also, we do not have to load lmodern)
+        # * else, color should be loaded before preview
         if match == None:
-            tmp.write(line)
-            continue
+            if polymatch == None:
+                tmp.write(line)
+                continue
+            else:
+                tmp.write(b"""
+\\usepackage{color}
+\\definecolor{fg}{rgb}{%s}
+\\definecolor{bg}{rgb}{%s}
+\\pagecolor{bg}
+\\usepackage{polyglossia}
+""" % (fg_color_gr, bg_color_gr))
+                polyglossia = True
+                continue
         success = 1
-        # Package order: color should be loaded before preview
         # Preview options: add the options lyx and tightpage
-        tmp.write(r"""
-\usepackage{color}
-\definecolor{fg}{rgb}{%s}
-\definecolor{bg}{rgb}{%s}
-\pagecolor{bg}
-\usepackage[%s,tightpage]{preview}
-\makeatletter
-\def\t@a{cmr}
-\if\f@family\t@a
-\IfFileExists{lmodern.sty}{\usepackage{lmodern}}{\usepackage{ae,aecompl}}
-\fi
-\g@addto@macro\preview{\begingroup\color{bg}\special{ps::clippath fill}\color{fg}}
-\g@addto@macro\endpreview{\endgroup}
-\makeatother
-""" % (fg_color_gr, bg_color_gr, match.group(1)))
-
+        previewopts = match.group(1)
+        if not polyglossia:
+            tmp.write(b"""
+\\usepackage{color}
+\\definecolor{fg}{rgb}{%s}
+\\definecolor{bg}{rgb}{%s}
+\\pagecolor{bg}
+\\usepackage[%s,tightpage]{preview}
+\\makeatletter
+\\def\\t@a{cmr}
+\\if\\f@family\\t@a
+\\IfFileExists{lmodern.sty}{\\usepackage{lmodern}}{\\usepackage{ae,aecompl}}
+\\fi
+\\g@addto@macro\\preview{\\begingroup\\color{bg}\\special{ps::clippath fill}\\color{fg}}
+\\g@addto@macro\\endpreview{\\endgroup}
+\\makeatother
+""" % (fg_color_gr, bg_color_gr, previewopts))
+        else:
+            tmp.write(b"""
+\\usepackage[%s,tightpage]{preview}
+\\makeatletter
+\\g@addto@macro\\preview{\\begingroup\\color{bg}\\special{ps::clippath fill}\\color{fg}}
+\\g@addto@macro\\endpreview{\\endgroup}
+\\makeatother
+""" % previewopts)
     if success:
         copyfileobj(tmp, open(latex_file,"wb"), 1)
 
@@ -255,7 +281,7 @@ def crop_files(pnmcrop, basename):
     t.append('%s -right' % pnmcrop, '--')
 
     for file in glob.glob("%s*.ppm" % basename):
-        tmp = mkstemp()
+        tmp = tempfile.TemporaryFile()
         new = t.open(file, "r")
         copyfileobj(new, tmp)
         if not new.close():
@@ -275,7 +301,7 @@ def legacy_conversion(argv, skipMetrics = False):
     if len(dir) != 0:
         os.chdir(dir)
 
-    dpi = string.atoi(argv[2])
+    dpi = int(argv[2])
 
     output_format = argv[3]
 
@@ -417,6 +443,10 @@ def legacy_conversion_step3(latex_file, dpi, output_format, dvips_failed, skipMe
     pdftocairo = find_exe(["pdftocairo"])
     epstopdf   = find_exe(["epstopdf"])
     use_pdftocairo = pdftocairo != None and output_format == "png"
+    if use_pdftocairo and os.name == 'nt':
+        # On Windows, check for png support (see #10718)
+        conv_status, conv_stdout = run_command("%s --help" % pdftocairo)
+        use_pdftocairo = '-png' in conv_stdout
     if use_pdftocairo:
         conv = pdftocairo
     else:
